GET  FILE='C:\MICS\SPSS\CH.sav'.

select if (AN1 < 99.0 and AN2 < 999.0).

graph 
  /scatterplot(bivar)=AN2 with AN1
  /missing=listwise
  /title = 'Figure 1. Scatterplot of weight (Y-axis) by height (x-axis) (unweighted), BELARUS, 2005'.

* calculate the CMC date of interview.
compute cmcdoic = (UF8Y - 1900)*12 + UF8M.
variable label cmcdoic "Date of interview child (CMC)".

* set random number seed.
set seed = 1003.

* calculate CMC date of birth and age (in months).
do if (UF10Y < 9996 and UF10M < 96).
+ compute cdob = (UF10Y - 1900)*12 + UF10M.
else if (UF10Y < 9996).
+ compute aldob = cmcdoic - (UF11*12) - 11.
+ compute audob = cmcdoic - (UF11*12) - 0.
+ compute ldob = (UF10Y - 1900)*12 + 1.
+ compute udob = (UF10Y - 1900)*12 + 12.
+ if (ldob >= aldob & ldob <= audob) cdob = trunc(rv.uniform(ldob,audob)).
+ if (aldob >= ldob & aldob <= udob) cdob = trunc(rv.uniform(aldob,udob)).
+ if (ldob > audob | aldob > udob) cdob = trunc(rv.uniform(aldob,audob)).
else.
+ compute aldob = cmcdoic - (UF11*12) - 11.
+ compute audob = cmcdoic - (UF11*12) - 0.
+ compute cdob = trunc(rv.uniform(aldob,audob)).
end if.
if (cmcdoic - cdob = 60) cdob = cdob + 1.
if (cdob <> 9999) cage = cmcdoic - cdob.
variable label cage "Age (months)".
variable label cdob "Date of birth (CMC)".
missing values cdob (9999).
format cage (f3.0).

graph 
  /scatterplot(bivar)=cage with AN1
  /missing=listwise
  /title = 'Figure 2. Scatterplot of weights of children by age in months (unweighted), BELARUS, 2005'.


graph 
  /scatterplot(bivar)=cage with AN2
  /missing=listwise
  /title = 'Figure 3. Scatterplot of heights of children by age in months (unweighted), BELARUS, 2005'.


GET  FILE='C:\MICS\SPSS\HL.sav'.

miss val hl5 (98, 99).

* Select males.
compute filter_$=(HL4 = 1).
filter by filter_$.

graph
  /line(simple)=count by HL5
  /title= 'Figure 4. Number of male household population (Y-axis) by single ages (X-axis) (unweighted), BELARUS, 2005'.


* Select females.
use all.
compute filter_$=(HL4 = 2).
filter by filter_$.

graph
  /line(simple)=count by HL5
  /title= 'Figure 5. Number of female household population (Y-axis) by single ages (X-axis) (unweighted), BELARUS, 2005'.

weight by hhweight.

* Select males.
compute filter_$=(HL4 = 1).
filter by filter_$.

graph
  /line(simple)=count by HL5
  /title= 'Figure 4. Number of male household population (Y-axis) by single ages (X-axis) (weighted), BELARUS, 2005'.


* Select females.
use all.
compute filter_$=(HL4 = 2).
filter by filter_$.

graph
  /line(simple)=count by HL5
  /title= 'Figure 5. Number of female household population (Y-axis) by single ages (X-axis) (weighted), BELARUS, 2005'.

GET  FILE='C:\MICS\SPSS\HL.sav'.

weight by hhweight.

recode HL5  (0 thru 4 = 1) (5 thru  9 =2 ) (10 thru  14 = 3) (15 thru  19 = 4) (20 thru 24 = 5) ( 25  thru 29 = 6) (30 thru  34 = 7) (35 thru 39 = 8)
                     (40 thru  44 = 9) (45 thru 49 = 10) (50 thru 54 = 11) (55 thru  59 = 12) (60 thru 64 = 13) (65 thru  69 = 14)  (70 thru 74 = 15) 
                     (75 thru 79 = 16) (80 thru 84 = 17) (85 thru 89 = 18) (90 thru 97 = 19) 
                     (98 thru hi = 99) into memage.
variable labels memage "Age group".
miss val memage (99).

value labels memage
 1     "0-4"
 2     "5-9"
 3   "10-14"
 4   "15-19"
 5   "20-24"
 6   "25-29"
 7   "30-34"
 8   "35-39"
 9   "40-44"
 10   "45-49"
 11   "50-54"
 12   "55-59"
 13   "60-64"
 14   "65-69"
 15   "70-74"
 16   "75-79"
 17   "80-84"
 18   "85-89"
 19   "90+"
 99   "Missing/DK".

var level memage (ordinal).


xgraph chart = ([count][bar]) by memage[c] by hl4[c]
   /coordinate split = yes
 /titles
   title = 'Figure 6. Population pyramid, BELARUS, 2005'.

new file.
