*open the household listing data file.
GET FILE='C:\MICS\SPSS\HL.sav'.

* create a variable that will reflect mother's line number.
COMPUTE Mline = hl1

* create what will be mother's education level.
RECODE ED3A (1 = 2) (4 = 3) (2 = 4) (5 = 5) (3 = 6) (6 = 7) (8,9 = 9) (else = 1) into Mlevel.
variable label Mlevel "Mother's education".
value label Mlevel
  1 "None"
  2 "Primary"
  3 "Incomplete secondary"
  4 "Secondary"
  5 "Primary/secondary professional"
  6 "Higher"
  7 "Non-standard curriculum"
  8 "Mother not in household" 
  9 "Missing/DK".

* sort the cases by cluster number, household number and mother's line number.
SORT CASES by HH1 HH2 Mline.

* save a mother's education file.
SAVE OUTFILE = 'C:\MICS\SPSS\tmpM.sav'
  /keep HH1 HH2 Mline Mlevel.

* create a variable that will reflect father's line number.
COMPUTE Fline = hl1

* create what will be father's education level.
RECODE ED3A (1 = 2) (4 = 3) (2 = 4) (5 = 5) (3 = 6) (6 = 7) (8,9 = 9) (else = 1) into Flevel.
variable label Flevel "Father's education".
value label Flevel
  1 "None"
  2 "Primary"
  3 "Incomplete secondary"
  4 "Secondary"
  5 "Primary/secondary professional"
  6 "Higher"
  7 "Non-standard curriculum"
  8 "Father not in household" 
  9 "Missing/DK".

* sort the cases by cluster number, household number and father's line number.
SORT CASES by HH1 HH2 Fline.

* save a father's education file.
SAVE OUTFILE = 'C:\MICS\SPSS\tmpF.sav'
  /keep HH1 HH2 Fline Flevel.

* keep heads of household only.
SELECT IF (hl3 = 1).

* create head of household's education level.
RECODE ED3A (1 = 2) (4 = 3) (2 = 4) (5 = 5) (3 = 6) (6 = 7) (8,9 = 9) (else = 1) into HHlevel.
variable label HHlevel "Education of household head".
value label HHlevel
  1 "None"
  2 "Primary"
  3 "Incomplete secondary"
  4 "Secondary"
  5 "Primary/secondary professional"
  6 "Higher"
  7 "Non-standard curriculum"
  9 "Missing/DK".

* sort the cases by cluster number, household number and head's line number.
SORT CASES by HH1 HH2 HL1.

* save a household head's education file.
SAVE OUTFILE = 'C:\MICS\SPSS\tmpHH.sav'
  /keep HH1 HH2 HL1 HHlevel.

* open the household listing data file.
GET FILE='C:\MICS\SPSS\HL.sav'.

* compute mother's line number for household members aged 17 or younger.
IF (HL7 <> 0) Mline = HL7.
IF (HL8 <> 0) Mline = HL8.
IF (hl5 < 18 and sysmis(Mline)) Mline = 0.

* use mother's line number if mother/caretaker from HL7 & HL8 is not available.
IF (Mline=0 and not sysmis(HL10) and HL10 <> 0) Mline = HL10.
variable label Mline "Mother's line number".

* sort the cases by cluster number, household number and mother's line number.
SORT CASES by HH1 HH2 mline.

* merge the mother's education file onto the household listing file.
MATCH FILES
  /file = *
  /table = 'C:\MICS\SPSS\tmpM.sav'
  /by HH1 HH2 Mline.

* recode mother's education level to deal with mothers who live elsewhere or are dead.
IF (Mline = 0) Mlevel = 8.

* compute father's line number for household members aged 17 or younger.
COMPUTE Fline = HL12.
IF (hl5 < 18 and sysmis(Fline)) Fline = 0.
variable label Fline "Father's line number".

* sort the cases by cluster number, household number and father's line number.
SORT CASES by HH1 HH2 Fline.

* merge the father's education file onto the household listing file.
MATCH FILES
  /file = *
  /table = 'C:\MICS\SPSS\tmpF.sav'
  /by HH1 HH2 Fline.

* recode father's education level to deal with fathers who live elsewhere or are dead.
IF (Fline = 0) Flevel = 8.

* sort the cases by cluster number and household number.
SORT CASES by HH1 HH2.

* merge the household head file onto the household listing file.
MATCH FILES
  /file = *
  /table = 'C:\MICS\SPSS\tmpHH.sav'
  /by HH1 HH2 .

* sort the cases by cluster number, household number and line number.
SORT CASES by HH1 HH2 HL1 .

* save the household listing data file.
SAVE OUTFILE = 'C:\MICS\SPSS\HL.sav'.

* erase the working files.
ERASE FILE = 'C:\MICS\SPSS\tmpHH.sav'.
ERASE FILE = 'C:\MICS\SPSS\tmpM.sav'.
ERASE FILE = 'C:\MICS\SPSS\tmpF.sav'.
