* open the women file.
GET FILE='C:\MICS\SPSS\WM.sav'.

* calculate the CMC date of interview.
COMPUTE cmcdoiw = (WM6Y - 1900)*12 + WM6M.
variable label cmcdoiw "Date of interview women (CMC)".

* set random number seed.
SET seed = 1003.

* calculate the CMC date of birth and age.
do if (WM8Y < 9996 and WM8M < 96).
+ COMPUTE Wdob = (WM8Y - 1900)*12 + WM8M.
else if (WM8Y < 9996).
+ COMPUTE aldob = cmcdoiw - WM9*12 - 11.
+ COMPUTE audob = cmcdoiw - WM9*12 - 0.
+ COMPUTE ldob = (WM8Y - 1900)*12 + 1.
+ COMPUTE udob = (WM8Y - 1900)*12 + 12.
+ if (ldob >= aldob & ldob <= audob) Wdob = trunc(rv.uniform(ldob,audob)).
+ if (aldob >= ldob & aldob <= udob) Wdob = trunc(rv.uniform(aldob,udob)).
+ if (ldob > audob | aldob > udob) Wdob = trunc(rv.uniform(aldob,audob)).
else.
+ COMPUTE aldob = cmcdoiw - WM9*12 - 11.
+ COMPUTE audob = cmcdoiw - WM9*12 - 0.
+ COMPUTE Wdob = trunc(rv.uniform(aldob,audob)).
end if.
IF (cmcdoiw - Wdob = 600) wdob = wdob + 1.
variable label Wdob "Date of birth (CMC)".
missing values Wdob (9999).

* calculate age in year groups.
RECODE WM9 (15 thru 19 = 1) (20 thru 24 = 2) (25 thru 29 = 3) (30 thru 34 = 4) 
	(35 thru 39 = 5) (40 thru 44 = 6) (45 thru 49 = 7) into Wage.
variable label Wage "Age".
value label Wage
  1 "15-19"
  2 "20-24"
  3 "25-29"
  4 "30-34"
  5 "35-39"
  6 "40-44"
  7 "45-49".

* calculate age at first marriage.
do if (MA6Y < 9996 and MA6M < 96).
COMPUTE Wdom = (MA6Y - 1900)*12 + MA6M.
COMPUTE agem = trunc ((wdom-wdob)/12) .
else if (MA8 < 96).
COMPUTE agem = MA8.
else if (not sysmis(MA6M)).
COMPUTE agem = 99.
end if.
variable label agem "Age at first marriage/union".
missing values agem (99).

* calculate marital status.
IF (MA1 = 1 or MA1  = 2) Mstatus = 1.
IF (MA3 = 1 or MA3  = 2) Mstatus = 2.
IF (MA3 = 3) Mstatus = 3.
variable label Mstatus "Marital/Union status".
value label Mstatus
  1 "Currently married/in union"
  2 "Formerly married/in union"
  3 "Never married/in union".

* calculate education level.
RECODE WM11 (1 = 2) (4 = 3) (2 = 4) (5 = 5) (3 = 6) (6 = 7) (8,9 = 9) (else = 1) into Mlevel.
variable label Mlevel "Education".
value label Mlevel
  1 "None"
  2 "Primary"
  3 "Incomplete secondary"
  4 "Secondary"
  5 "Primary/secondary professional"
  6 "Higher"
  7 "Non-standard curriculum"
  9 "Missing/DK".

* calculate total children ever born.
COMPUTE ceb = 0.
IF (CM1 = 1) ceb = CM9.
variable label ceb "Children ever born".

* calculate number of dead children.
COMPUTE deadkids = 0.
IF (CM7 = 1) deadkids = CM8A + CM8B.
variable label deadkids "Dead children".

* reset variables for incomplete interviews.
do if (WM7 ~= 1).
+ RECODE Wdob (lo thru hi=sysmis).
+ RECODE Wage (lo thru hi=sysmis).
+ RECODE Wdom (lo thru hi=sysmis).
+ RECODE agem (lo thru hi=sysmis).
+ RECODE Mstatus (lo thru hi=sysmis).
+ RECODE Mlevel (lo thru hi=sysmis).
+ RECODE ceb (lo thru hi=sysmis).
+ RECODE deadkids (lo thru hi=sysmis).
end if.

*save the women's file.
SAVE OUTFILE = 'C:\MICS\SPSS\WM.sav'
   /drop aldob audob ldob udob Wdom.
