*------------------------------------------------------------------------------------------------- VARIABLES FROM HOUSEHOLD.
GET FILE='C:\MICS\SPSS\HH.sav'.
subgroup.
select if (HH9 = 1).
compute hhweight = hhweight*CD7*1000000.
match files
  /file = *
  /table = 'pairs.sav'
  /by HH1.

*--------------------------------------------------------------------------------------------------------- Child discipline.
do if (not sysmis(CD12A)).
+ compute punish = 0.
+ if (CD12D = 1 or CD12H = 1) punish = 1.
+ if (CD12C = 1 or CD12F = 1 or CD12G = 1 or CD12J = 1) punish = 1.
+ if (CD12I = 1 or CD12K = 1) punish = 1.
end if.
variable label punish "Child discipline".

*------------------------------------------------------------------------------------------------ Calculate sampling errors.
CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=hhweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = punish
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.

*----------------------------------------------------------------------------------------- VARIABLES FROM HOUSEHOLD LISTING.
GET FILE='C:\MICS\SPSS\HL.sav'.
subgroup.
compute hhweight = hhweight*1000000.
match files
  /file = *
  /table = 'pairs.sav'
  /by HH1.

*----------------------------------------------------------------------------------- Use of improved drinking water sources.
compute improved = 0.
if (WS1 = 11 or  WS1 = 12 or WS1 = 13 or WS1 = 31) improved = 1.
if ((WS2 = 11 or WS2 = 12 or WS2 = 13 or WS2 = 31) and WS1 = 91) improved = 1. 
variable label improved "Use of improved drinking water sources".

*------------------------------------------------------------------------------------ Use of improved sanitation facilities.
recode WS7 (11,12,13,21,22,31 = 1) (else = 0) into sanitary.
variable label sanitary "Use of improved sanitation facilities".

*--------------------------------------------------------------------------------------- Net primary school attendance rate.
* select children who are of primary school age; this definition is
* country-specific and should be changed to reflect the situation in your country.

do if (HL5 >= 6 and HL5 <= 9).
+ compute primary  = 0.
+ if (ED6A >= 1 and ED6A <= 2) primary =  1.
end if.
variable label primary "Net primary school attendance rate".

*------------------------------------------------------------------------------------- Net secondary school attendance rate.
* select children who are of secondary school age; this definition is
* country-specific and should be changed to reflect the situation in your country.

do if (HL5 >= 10 and HL5 <= 16).
+ compute second  = 0.
+ if (ED6A >= 2 and ED6A <= 3 or ED6A = 5) second =  1.
end if.
variable label second "Net secondary school attendance rate".

*-------------------------------------------------------------------------------------------------- Primary completion rate.
* select children who are of primary school graduation age; this definition is
* country-specific and should be changed to reflect the situation in your country.

* Primary school graduation age.
compute maxage = 9.
* Last primary grade.
compute higrade = 4.
do if (HL5 = maxage).
+ compute plgrade = 0.
+ if ((ED6A = 1 and ED6B >= higrade and ED6B < 8) or (ED6A >= 2 and ED6A < 8)) plgrade = 1.
* Exclude repeats.
+ if (ED8A = ED6A and ED8B  = ED6B) plgrade = 0.
end if.
variable label plgrade "Primary completion rate".

*------------------------------------------------------------------------------------------------------------- Child labour.
if (HL5 >= 5 and HL5 <= 14) working = 0.
recode CL4 CL9 (98,99,sysmis = 0) .
compute hours = CL4 + CL9.
if ((HL5 >= 5 and HL5 <= 11) and (CL3 = 1 or CL3 = 2 or CL8 = 1 or (CL7 >= 28 and CL7 <= 95))) working = 1.
if ((HL5 >= 12 and HL5 <= 14) and ((CL7 >= 28 and CL7 <= 95) or (hours >= 14 and hours <= 190))) working = 1.
variable label working "Child labour".

*------------------------------------------------------------------------------------------------------------------ Orphans.
do if (HL5 <= 17).
+ compute orphan = 0.
+ if (HL9 = 2 or HL11 = 2) orphan = 1.
end if.
variable label orphan "Prevalence of orphans".

*------------------------------------------------------------------------------------------------ Calculate sampling errors.
CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=hhweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = improved sanitary primary second plgrade working orphan
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.

*----------------------------------------------------------------------------------------------------- VARIABLES FROM WOMEN.
GET FILE='C:\MICS\SPSS\WM.sav'.
subgroup.
select if (WM7 = 1).
compute wmweight = wmweight*1000000.
match files
  /file = *
  /table = 'pairs.sav'
  /by HH1.

*-------------------------------------------------------------------------------------------- Skilled attendant at delivery.
do if (CM12 = 1).
+ compute skilled = 0.
+ if (MN7A = "A" or MN7B = "B" or MN7C = "C") skilled = 1.
end if.
variable label skilled "Skilled attendant at delivery".

*----------------------------------------------------------------------------------------------------------- Antenatal care.
do if (CM12 = 1).
+ compute ancskill = 0.
+ if (MN2A = "A" or MN2B = "B" or MN2C = "C") ancskill = 1.
end if.
variable label ancskill "Antenatal care".

*------------------------------------------------------------------------------------------------- Contraceptive prevalence.
do if (mstatus = 1).
+ compute anymeth = 0.
+ if (CP2 = 1) anymeth = 1.
end if.
variable label anymeth "Contraceptive prevalence".

*----------------------------------------------------------------------------------------------------------- Adult literacy.
do if (WM9 >= 15 and WM9 <= 24).
+ compute literate  = 0.
+ if (WM14 = 3 or WM11 = 2 or WM11 = 3 or WM11 = 4 or WM11 = 5) literate = 1.
end if.
variable label literate "Adult literacy".

*--------------------------------------------------------------------------------------------------- Marriage before age 18.
do if (WM9 >= 20).
+ compute agem18 = 0.
+ if (agem < 18) agem18 = 1.
end if.
variable label agem18 "Marriage before age 18".

*----------------------------------------------------------------------------------- Comprehensive correct knowledge of HIV.
do if (WM9 >= 15 and WM9 <= 24).
+ compute compre = 0.
if ((HA2 = 1 and HA4 = 1) and (HA7 = 2 and HA5 = 2 and HA8 = 1)) compre = 1.
end if.
variable label compre "Comprehensive knowledge about HIV prevention among young people".

*------------------------------------------------------------------------------ Accepting attitudes towards people with HIV.
do if (HA1 = 1).
+ compute accept = 1.
+ if (HA13 = 2 or HA12 = 1 or HA10 = 2 or HA11 = 2) accept = 0.
end if.
variable label accept "Attitudes towards people with HIV/AIDS".

*--------------------------------------------------------------------------------------- Women who have been tested for HIV.
compute tested = 0.
if (HA15 = 1 or MN5 = 1) tested = 1.
variable label tested "Women who have been tested for HIV".

*---------------------------------------------------------------------------------------- Know mother to child transmission.
compute knowmtct = 0.
if (HA9A = 1 and HA9B = 1 and HA9C = 1) knowmtct = 1.
variable label knowmtct "Knowledge of mother-to-child transmission of HIV".

*------------------------------------------------------------------------------------------------ Calculate sampling errors.
CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=wmweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = skilled ancskill anymeth literate agem18 compre accept tested knowmtct
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.


*-------------------------------------------------------------------------------------------- VARIABLES FROM CHILDRENS DATA.
GET FILE='C:\MICS\SPSS\CH.sav'.
subgroup.
select if (UF9 = 1).
compute chweight = chweight*1000000.
match files
  /file = *
  /table = 'pairs.sav'
  /by HH1.

*--------------------------------------------------------------------------------------------------- Underweight Prevalence.
compute misshw = 0.
if (AN1 >= 99.0 or AN2 >= 999.0) misshw = 100.
variable label misshw "Missing height or weight".

do if (misshw = 0).
+ recode WAZ (-2.00 thru hi = 0) (else = 1) into wa2.
else.
+ compute wa2 = 9.
end if.
if (flag ne 0)  wa2 = 9.

variable label wa2 "Underweight prevalence".
missing values wa2 (9).

*------------------------------------------------------------------------------------------------------------ Immunizations.
include file = "C:\MICS\SPSS\04 - chrecvac.sps".

do if (cage >= 18 and cage <= 29).
+ recode bcg (1,2 = 1) (else = 0) into bcg_r.
+ recode dpt3 (1,2 = 1) (else = 0) into dpt3_r.
+ recode polio3 (1,2 = 1) (else = 0) into polio3_r.
+ recode MMR (1,2 = 1) (else = 0) into MMR_r.
+ recode allvacc (1,2 = 1) (else = 0) into all_r.
end if.
variable label bcg_r "Tuberculosis immunization coverage".
variable label dpt3_r "Immunization coverage for DPT".
variable label polio3_r "Polio immunization coverage".
variable label MMR_r "MMR immunization coverage".
variable label all_r "Fully immunized children".

*------------------------------------------------------------------------------Antibiotic treatment of suspected pneumonia.
* ARI in the last 2 weeks.

compute ari  = 0.
if ((CA7 = 1 or CA7 = 3) and CA5 = 1 and CA6 = 1) ari = 1.
variable label ari "Acute respiratory infection in last two weeks".

do if (ari = 1).
+ recode CA11A ("A" = 1) (else = 0) into anti.
end if.
variable label anti "Antibiotic treatment of suspected pneumonia".

*------------------------------------------------------------------ Received ORT or increased fluids, and continued feeding.
* Diarrhoea in last 2 weeks.

recode CA1 (1 = 1) (else = 0) into diarrhea.
variable label diarrhea "Diarrhoea in last two weeks".

do if (diarrhea = 1).
+ compute orifcf = 0.
+ if ((CA2A = 1 or CA2B = 1 or CA2C = 1 or CA3 = 3) and (CA4 = 3 or CA4 = 4 or CA4 = 5)) orifcf = 1.
end if.
variable label orifcf "Received ORT or increased fluids and continued feeding".

*----------------------------------------------------------------------------------------------------- Support for learning.
compute activity = 0.
if (BR8AM = "A" or BR8AF = "B" or BR8AO = "X") activity = activity + 1.
if (BR8BM = "A" or BR8BF = "B" or BR8BO = "X") activity = activity + 1.
if (BR8CM = "A" or BR8CF = "B" or BR8CO = "X") activity = activity + 1.
if (BR8DM = "A" or BR8DF = "B" or BR8DO = "X") activity = activity + 1.
if (BR8EM = "A" or BR8EF = "B" or BR8EO = "X") activity = activity + 1.
if (BR8FM = "A" or BR8FF = "B" or BR8FO = "X") activity = activity + 1.
variable label activity "Mean number of activities household members engage in with the child".

recode activity (4 thru hi = 1) (else = 0) into activ4.
variable label activ4 "Support for learning".

*------------------------------------------------------------------------------------------------------------------------- Calculate sampling errors.
CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=chweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = wa2 bcg_r polio3_r dpt3_r MMR_r all_r ari anti diarrhea orifcf activ4
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.

new file.