GET  FILE='C:\MICS\SPSS\HL.sav'.

select if (hl5 >= 10 and hl5 <= 54 and hl4 = 2).

recode hl5 (10 thru 14 = 0)  (15 thru 19 = 1) (20 thru 24 = 2) (25 thru 29 = 3) (30 thru 34 = 4) 
	(35 thru 39 = 5) (40 thru 44 = 6) (45 thru 49 = 7) (50 thru 54 = 8) into hlage.
variable label hlage "Age".
value label hlage
  0 "10-14"
  1 "15-19"
  2 "20-24"
  3 "25-29"
  4 "30-34"
  5 "35-39"
  6 "40-44"
  7 "45-49"
  8 "50-54".

weight by HHWEIGHT.

compute t1054 = 1.
if (hl5 >= 15 and hl5 <= 49) t1549 = 1.

if (hl5 >= 15 and hl5 <= 49) total = 1.
variable label total "15-49".
value label total 1 "".

aggregate outfile ="tmp1.sav"
  /break   = hlage
  /tt1054  = sum(t1054)
  /tt1549  = sum(t1549).

aggregate outfile = "tmp2.sav"
  /break   = total
  /tt1054  = sum(t1054)
  /tt1549  = sum(t1549).

get file = 'tmp1.sav'.
add files
  /file = *
  /file = 'tmp2.sav'.

sort cases by hlage total.

save out="tmp1.sav".

GET  FILE='C:\MICS\SPSS\HL.sav'
 /keep HH1 HH2 HL1 HL5 hhweight
 /rename (HL1=LN).

sort cases hh1 hh2 ln.

save out="tmp1c.sav".


GET  FILE='C:\MICS\SPSS\WM.sav'.

sort cases by HH1 HH2 ln.

match files 
 /file=*
 /table='tmp1c.sav'
 /by HH1 HH2 ln.

select if (WM7 = 1).

weight by HHWEIGHT.

compute total  = 1.
variable label total "Total".
value label total 1 "".

recode hl5 (10 thru 14 = 0)  (15 thru 19 = 1) (20 thru 24 = 2) (25 thru 29 = 3) (30 thru 34 = 4) 
	(35 thru 39 = 5) (40 thru 44 = 6) (45 thru 49 = 7) (50 thru 54 = 8) into hlage.
variable label hlage "Age".
value label hlage
  0 "10-14"
  1 "15-19"
  2 "20-24"
  3 "25-29"
  4 "30-34"
  5 "35-39"
  6 "40-44"
  7 "45-49"
  8 "50-54".

compute t1549i = 0.
if (WM7 = 1) t1549i = 1.
if (WM7 = 1) elig = 1.

aggregate outfile ="tmp3.sav"
  /break   = hlage
  /tt1549i = sum(t1549i)
  /telig  = sum(elig).

aggregate outfile = "tmp4.sav"
  /break   = total
  /tt1549i = sum(t1549i)
  /telig  = sum(elig).

get file = 'tmp3.sav'.
add files
  /file = *
  /file = 'tmp4.sav'.

sort cases by hlage total.
save out="tmp3.sav".

get file="tmp1.sav".
match files 
 /file=*
 /table='tmp3.sav'
 /by  hlage total.

variable label tt1054 'Household population of women age 10-54'.
variable label tt1549i 'Interviewed women age 15-49'.

compute pelig = (tt1549i/tt1549)*100.
variable label pelig "Percentage of eligible women interviewed".

tables
  /format = zero
  /observation= tt1054 tt1549i pelig
  /table= hlage + total by tt1054 + tt1549i + pelig 
  /statistics
    sum(tt1054 (f5.0) 'Number')
    sum(tt1549i (f5.0) 'Number')
    spct(tt1549i (f5.1) 'Percent')
    means(pelig (f5.1) ' ')
  /title
    "Table DQ.2: Age distribution of eligible and interviewed women"
                       "Household population of women age 10-54, interviewed women age 15-49, and percentage of " +
                       "eligible women who were interviewed (weighted), by five-year age group, BELARUS, 2005".

new file.
erase file 'tmp1.sav'.
erase file 'tmp1c.sav'.
erase file 'tmp2.sav'.
erase file 'tmp3.sav'.
erase file 'tmp4.sav'.
