GET  FILE='C:\MICS\SPSS\WM.sav'.

select if (WM7 = 1).

weight by WMWEIGHT.

compute total = 1.
variable label total "Total".
value label total 1 "".

compute women  = 1.
value labels women 1 "".

if (CM1 = 1 and (missing(CM4A))) CM4A  = 0.
if (CM1 = 1 and (missing(CM4B))) CM4B  = 0.
if (CM1 = 1 and (missing(CM6A))) CM6A  = 0.
if (CM1 = 1 and (missing(CM6B))) CM6B  = 0.
if (CM1 = 1 and (missing(CM8A))) CM8A  = 0.
if (CM1 = 1 and (missing(CM8B))) CM8B  = 0.

* calculate total children ever born.
compute cebs = 0.
if (CM1 = 1) cebs = CM4A + CM6A + CM8A.
variable label cebs "Children ever born sons".

* calculate total children ever born.
compute cebd = 0.
if (CM1 = 1) cebd = CM4B + CM6B + CM8B.
variable label cebd "Children ever born daughters".

* calculate number of dead children.
compute deads = 0.
if (CM7 = 1) deads = CM8A .
variable label deads "Dead sons".

* calculate number of dead children.
compute deadd = 0.
if (CM7 = 1) deadd =  CM8B.
variable label deadd "Dead daughters".

compute livings = 0.
if (CM1 = 1) livings = CM4A + CM6A.
variable label livings "Living sons".

compute livingd = 0.
if (CM1 = 1) livingd = CM4B + CM6B.
variable label livingd "Living daughters".

aggregate outfile = 'tmp1.sav'
  /break   = wage
  /tcebs  = sum(cebs)
  /tcebd  = sum(cebd)
  /tlivings  = sum(livings)
  /tlivingd  = sum(livingd)
  /tdeads  = sum(deads)
  /tdeadd  = sum(deadd)
  /twomen = sum(women).

aggregate outfile = 'tmp2.sav'
  /break   = total
  /tcebs  = sum(cebs)
  /tcebd  = sum(cebd)
  /tlivings  = sum(livings)
  /tlivingd  = sum(livingd)
  /tdeads  = sum(deads)
  /tdeadd  = sum(deadd)
  /twomen = sum(women).

get file = 'tmp1.sav'.

add files
  /file = *
  /file = 'tmp2.sav'.

variable label
  tcebs   "Number of sons ever born"
  /tcebd   "Number of daughters ever born"
  /tlivings "Number of sons living"
  /tlivingd  "Number of daughters living"
  /tdeads   "Number of deceased sons"
  /tdeadd   "Number of deceased daughters"
  /twomen  "Number of women".

if (tcebd > 0) sceb = (tcebs/tcebd).
variable label sceb "Sex ratio of children ever born".

if (tlivingd > 0) sliving = (tlivings/tlivingd).
variable label sliving "Sex ratio of living children".

if (tdeadd > 0) sdead = (tdeads/tdeadd).
variable label sdead "Sex ratio of deceased children".

tables
  /format = zero
  /ftotal = tot1 "Total"
  /observation = tcebs tcebd tlivings tlivingd tdeads tdeadd sceb sliving sdead twomen 
  /table = wage + total by tcebs + tcebd + sceb + tlivings + tlivingd + sliving + tdeads + tdeadd + sdead + twomen 
  /statistics
    sum(tcebs '' (f5.0))
    sum(tcebd '' (f5.0))
    mean(sceb '' (f5.2))
    sum(tlivings '' (f5.0))
    sum(tlivingd '' (f5.0))
    mean(sliving '' (f5.2))
    sum(tdeads '' (f5.0))
    sum(tdeadd '' (f5.0))
    mean(sdead '' (f5.2))
    sum(twomen '' (f5.0))
  /title
    "Table DQ.9: Sex ratio at birth among children ever born and living" 
    "Sex ratio at birth among children ever born, children living, and deceased children by age of women (weighted), BELARUS, 2005".

new file.

*delete working files.
erase file = 'tmp1.sav'.
erase file = 'tmp2.sav'.
